plugins {
    alias(libs.plugins.android.application)
    alias(libs.plugins.jetbrains.kotlin.android)
    kotlin("kapt")
    alias(libs.plugins.hilt)
    alias(libs.plugins.google.services)
    alias(libs.plugins.secrets.gradle)
}

android {
    namespace = "com.jrl.fuelprice"
    compileSdk = 34
    defaultConfig {
        applicationId = "com.jrl.fuelprice"
        minSdk = 26
        targetSdk = 34
        versionCode = 2
        versionName = "0.0.2"
        testInstrumentationRunner = "androidx.test.runner.AndroidJUnitRunner"
    }
    buildTypes {
        release {
            isMinifyEnabled = false
            proguardFiles(getDefaultProguardFile("proguard-android-optimize.txt"), "proguard-rules.pro")
        }
    }
    buildFeatures {
        buildConfig = true
        compose = true
    }
    composeOptions {
        kotlinCompilerExtensionVersion = "1.5.11"
    }
    compileOptions {
        sourceCompatibility = JavaVersion.VERSION_1_8
        targetCompatibility = JavaVersion.VERSION_1_8
    }
    kotlinOptions {
        jvmTarget = "1.8"
    }
    secrets {
        propertiesFileName = "secrets.properties"
    }
    testOptions {
        unitTests {
            isIncludeAndroidResources = true
        }
    }
}

dependencies {
    // Android KTX
    implementation(libs.androidx.activity)
    implementation(libs.androidx.core.ktx)
    implementation(libs.appcompat)
    implementation(libs.lifecycle.runtime)
    implementation(libs.material)
    
    // Jetpack Compose
    implementation(libs.activity.compose)
    implementation(libs.androidx.material)
    implementation(libs.material3)
    implementation(libs.compose.ui)
    implementation(libs.navigation.compose)
    debugImplementation(libs.compose.ui.tooling)
    implementation(libs.compose.ui.tooling.preview)
    implementation(platform(libs.compose.bom))
    implementation(libs.guava)      // For ImmutableList class
    implementation(libs.compose.icons)
    implementation(libs.compose.maps)
    
    // Hilt - Injection dependencies
    kapt(libs.hilt.compiler)
    implementation(libs.hilt.android)
    implementation(libs.hilt.navigation.compose)
    implementation(libs.dagger)
    
    // Location
    implementation(libs.play.services.location)
    
    // Permissions
    implementation(libs.accompanist.permissions)
    
    // Network
    implementation(libs.okhttp)
    implementation(libs.okhttp.logging.interceptor)
    implementation(libs.retrofit)
    implementation(libs.retrofit.converter.gson)
    
    // Db
    kapt(libs.room.compiler)
    implementation(libs.room)
    
    // Firebase
    implementation(libs.firebase.firestore)
    implementation(libs.firebase.messaging)
    implementation(platform(libs.firebase.bom))
    
    // Search destinations
    implementation(libs.google.maps.services)
    // implementation(libs.places)
    implementation(libs.google.places)
    
    // Testing general
    testImplementation(libs.androidx.junit.ktx)
    androidTestImplementation(libs.androidx.junit.ktx)
    testImplementation(libs.junit.jupiter)
    testRuntimeOnly(libs.junit.jupiter.engine)
    testRuntimeOnly(libs.junit.vintage.engine)    // to run JUnit 4 tests using JUnit 5 engine
    testImplementation(libs.junit.jupiter.api)
    testImplementation(libs.junit.jupiter.params)
    testImplementation(libs.kotlinx.coroutines.test)
    testImplementation(libs.mockk)
    testImplementation(libs.kotlinx.coroutines.test)
    testImplementation(libs.kotest.assertions.core.jvm)
    androidTestImplementation(libs.kotest.assertions.core.jvm)
    testImplementation(libs.mockwebserver)
    testImplementation(libs.logback.classic)    // For logging in tests of MockWebServer
    testImplementation(libs.turbine)
    testImplementation(libs.kotlin.test)
    testImplementation(libs.robolectric)
    testImplementation(libs.junit)
    androidTestImplementation(libs.androidx.junit)
    androidTestImplementation(libs.espresso.core)
    testImplementation(libs.androidx.ui.test.junit4)
    debugImplementation(libs.androidx.ui.test.manifest)     // For test Compose with Robolectric
}

tasks.withType<Test>().configureEach {
    useJUnitPlatform()
}