package com.jrl.fuelprice.data.discounts.db.dao

import androidx.test.ext.junit.runners.AndroidJUnit4
import com.jrl.fuelprice.data.commons.AbsDaoTest
import com.jrl.fuelprice.data.discounts.db.entities.DiscountDbModel
import com.jrl.fuelprice.data.discounts.db.entities.DiscountTypeDbEnum
import io.kotest.matchers.shouldBe
import org.junit.Before
import org.junit.Test
import org.junit.runner.RunWith

@RunWith(AndroidJUnit4::class)
class DiscountDaoTest : AbsDaoTest() {
    
    private lateinit var discountDao: DiscountDao
    
    @Before
    override fun createDb() {
        super.createDb()
        discountDao = db.discountDao()
    }
    
    @Test
    @Throws(Exception::class)
    fun testDiscountsDao() {
        // 🔵 Given //
        val expectedDiscounts = listOf(
            DiscountDbModel(
                id = 1,
                brandId = 1,
                name = "ALCAMPO 3c/L",
                description = "Esto es la descripción de ALCAMPO",
                recipient = "",
                value = 3,
                type = DiscountTypeDbEnum.CENTS,
                isActive = true
            ),
            DiscountDbModel(
                id = 2,
                brandId = 2,
                name = "AVIA 5c/L",
                description = "Esto es la descripción de AVIA",
                recipient = "",
                value = 5,
                type = DiscountTypeDbEnum.CENTS,
                isActive = false
            ),
            DiscountDbModel(
                id = 3,
                brandId = 3,
                name = "BALLENOIL 10%/L",
                description = "Esto es la descripción de BALLENOIL",
                recipient = "",
                value = 10,
                type = DiscountTypeDbEnum.PERCENTAGE,
                isActive = false
            ),
        )
        discountDao.update(1, true)
        
        // 🟡 When //
        val discountsWithBrandDb = discountDao.getDiscounts()
        
        // 🟢 Then //
        discountsWithBrandDb.forEach { actual ->
            actual.discount.shouldBe(expectedDiscounts.find { it.id == actual.discount.id })
        }
    }
}