package com.jrl.fuelprice.data.alerts

import com.jrl.fuelprice.data.alerts.local.AlertLocalSource
import com.jrl.fuelprice.data.alerts.local.entities.AlertDbModel.Companion.toDb
import com.jrl.fuelprice.data.alerts.remote.AlertRemoteSource
import com.jrl.fuelprice.domain.alerts.AlertRepository
import com.jrl.fuelprice.domain.alerts.models.AlertDomainModel
import com.jrl.fuelprice.domain.alerts.models.AlertGasStationDomainModel
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow
import kotlinx.coroutines.flow.map
import javax.inject.Inject

class AlertRepositoryImpl @Inject constructor(
    private val dbSource: AlertLocalSource,
    private val remoteSource: AlertRemoteSource,
) : AlertRepository {
    
    override suspend fun getAlerts(
        userId: String,
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): Flow<List<AlertGasStationDomainModel>> = flow {
        remoteSource.getAlerts(userId = userId)
            .fold(
                onSuccess = {
                    dbSource.saveAlert(*it.map { it.toDb() }.toTypedArray())
                    dbSource.getFavorites(
                        fuelType = fuelType,
                        location = location,
                    ).map {
                        it.mapNotNull { it.toDomain(location) }
                    }.collect {
                        emit(it)
                    }
                },
                onFailure = { emit(emptyList()) },
            )
    }
    
    override suspend fun updateStatusAlert(
        alert: AlertDomainModel,
        userId: String,
    ) {
        remoteSource.updateAlertStatus(
            alert = alert,
            userId = userId,
        )
    }
}