package com.jrl.fuelprice.data.alerts.di

import com.google.firebase.firestore.FirebaseFirestore
import com.jrl.fuelprice.data.alerts.AlertRepositoryImpl
import com.jrl.fuelprice.data.alerts.local.AlertLocalSource
import com.jrl.fuelprice.data.alerts.local.AlertLocalSourceImpl
import com.jrl.fuelprice.data.alerts.local.dao.AlertDao
import com.jrl.fuelprice.data.alerts.remote.AlertRemoteSource
import com.jrl.fuelprice.data.alerts.remote.AlertRemoteSourceImpl
import com.jrl.fuelprice.domain.alerts.AlertRepository
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent

@Module
@InstallIn(SingletonComponent::class)
object AlertDataModule {
    
    @Provides
    fun providesAlertDbSource(
        dao: AlertDao,
    ): AlertLocalSource = AlertLocalSourceImpl(dao = dao)
    
    @Provides
    fun providesAlertRemoteSource(
        firestore: FirebaseFirestore,
    ): AlertRemoteSource = AlertRemoteSourceImpl(firestore = firestore)
    
    @Provides
    fun providesAlertRepository(
        dbSource: AlertLocalSource,
        remoteSource: AlertRemoteSource,
    ): AlertRepository = AlertRepositoryImpl(
        dbSource = dbSource,
        remoteSource = remoteSource,
    )
}