package com.jrl.fuelprice.data.alerts.local

import com.jrl.fuelprice.data.alerts.local.dao.AlertDao
import com.jrl.fuelprice.data.alerts.local.entities.AlertDbModel
import com.jrl.fuelprice.data.alerts.local.entities.AlertGasStationDbModel
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum.Companion.toText
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import kotlinx.coroutines.flow.Flow

class AlertLocalSourceImpl(
    private val dao: AlertDao,
) : AlertLocalSource {
    
    override suspend fun getFavorites(
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): Flow<List<AlertGasStationDbModel>> =
        dao.getAlerts(
            fuelType = fuelType.toText(),
            latitude = location?.latitude ?: 0.0,
            longitude = location?.longitude ?: 0.0,
        )
    
    override suspend fun saveAlert(vararg alert: AlertDbModel) {
        dao.insert(*alert)
    }
    
    override suspend fun removeAlert(alert: AlertDbModel) {
        dao.remove(alert)
    }
    
    override suspend fun updateAlert(alert: AlertDbModel) {
        dao.update(alert)
    }
}