package com.jrl.fuelprice.data.alerts.local.dao

import androidx.room.Dao
import androidx.room.Delete
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import androidx.room.Update
import com.jrl.fuelprice.data.alerts.local.entities.AlertDbModel
import com.jrl.fuelprice.data.alerts.local.entities.AlertGasStationDbModel
import kotlinx.coroutines.flow.Flow

@Dao
interface AlertDao {
    
    @Query(
        "SELECT alerts.is_enabled, gas_stations.*, (latitude-(:latitude))*(latitude-(:latitude))+(longitude-(:longitude))*(longitude-(:longitude)) AS distance_km FROM alerts INNER JOIN gas_stations ON alerts.gas_station_id = gas_stations.id WHERE is_favorite LIKE 1 AND latitude != 0.0 AND longitude != 0.0 AND CASE WHEN :fuelType = 'diesel_a' THEN diesel_a > 0.0 WHEN :fuelType = 'diesel_b' THEN diesel_b > 0.0 WHEN :fuelType = 'diesel_premium' THEN diesel_premium > 0.0 WHEN :fuelType = 'gasoline_95_e5' THEN gasoline_95_e5 > 0.0 WHEN :fuelType = 'gasoline_95_e5_premium' THEN gasoline_95_e5_premium > 0.0 WHEN :fuelType = 'gasoline_95_e10' THEN gasoline_95_e10 > 0.0 WHEN :fuelType = 'gasoline_98_e5' THEN gasoline_98_e5 > 0.0 WHEN :fuelType = 'gasoline_98_e10' THEN gasoline_98_e10 > 0.0 WHEN :fuelType = 'hydrogen' THEN hydrogen > 0.0 END ORDER BY CASE WHEN :fuelType = 'diesel_a' THEN diesel_a WHEN :fuelType = 'diesel_b' THEN diesel_b WHEN :fuelType = 'diesel_premium' THEN diesel_premium WHEN :fuelType = 'gasoline_95_e5' THEN gasoline_95_e5 WHEN :fuelType = 'gasoline_95_e5_premium' THEN gasoline_95_e5_premium WHEN :fuelType = 'gasoline_95_e10' THEN gasoline_95_e10 WHEN :fuelType = 'gasoline_98_e5' THEN gasoline_98_e5 WHEN :fuelType = 'gasoline_98_e10' THEN gasoline_98_e10 WHEN :fuelType = 'hydrogen' THEN hydrogen END  AND is_favorite == 1 ASC"
    )
    fun getAlerts(
        fuelType: String,
        latitude: Double,
        longitude: Double,
    ): Flow<List<AlertGasStationDbModel>>
    
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insert(vararg alert: AlertDbModel)
    
    @Update(onConflict = OnConflictStrategy.REPLACE)
    fun update(alert: AlertDbModel)
    
    @Delete
    fun remove(alert: AlertDbModel)
}