package com.jrl.fuelprice.data.alerts.remote

import com.google.firebase.firestore.FirebaseFirestore
import com.jrl.fuelprice.data.alerts.remote.models.AlertFirestoreFuelTypeEnum.Companion.toFirestore
import com.jrl.fuelprice.data.alerts.remote.models.AlertFirestoreModel
import com.jrl.fuelprice.data.alerts.remote.models.AlertFirestoreModel.Companion.fromDomain
import com.jrl.fuelprice.domain.alerts.models.AlertDomainModel
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.tasks.await
import kotlinx.coroutines.withContext

class AlertRemoteSourceImpl(
    private val firestore: FirebaseFirestore,
) : AlertRemoteSource {
    
    override suspend fun getAlerts(userId: String): Result<List<AlertDomainModel>> {
        return withContext(Dispatchers.IO) {
            try {
                val snapshot = firestore
                    .collection(AlertFirestoreModel.KEY_ALERT_DOCUMENT)
                    .whereEqualTo("pushToken", userId)
                    .get()
                    .await()
                val alerts = snapshot.documents.mapNotNull {
                    it?.let { AlertFirestoreModel.fromFirestoreToResponse(it) }
                }
                Result.success(alerts)
            } catch (exception: Exception) {
                Result.failure(exception)
            }
        }
    }
    
    override suspend fun updateAlertStatus(
        alert: AlertDomainModel,
        userId: String,
    ) {
        val firestoreFuelType = alert.fuelType.toFirestore()
        val documentId = "${alert.gasStationId}_${firestoreFuelType.value}_${userId}"
        val alertDocument = firestore.collection(AlertFirestoreModel.KEY_ALERT_DOCUMENT).document(documentId)
        val alertFirestore = alert.fromDomain(userId)
        alertDocument.set(alertFirestore)
            .addOnSuccessListener {
                println("DocumentSnapshot successfully written!")
            }
            .addOnFailureListener {
                println("Error writing document: $it")
            }
    }
}