package com.jrl.fuelprice.data.alerts.remote.models

import com.google.firebase.firestore.DocumentSnapshot
import com.jrl.fuelprice.data.alerts.remote.models.AlertFirestoreFuelTypeEnum.Companion.toFirestore
import com.jrl.fuelprice.domain.alerts.models.AlertDomainModel

data class AlertFirestoreModel(
    val priceCents: Int,
    val gasStationId: Int,
    val gasStationName: String,
    val fuelType: Int,
    val pushToken: String,
    val enabled: Boolean,
) {
    
    companion object {
        const val KEY_ALERT_DOCUMENT = "alerts"
        
        fun AlertDomainModel.fromDomain(pushToken: String): AlertFirestoreModel {
            return AlertFirestoreModel(
                priceCents = this.priceCents,
                gasStationId = this.gasStationId,
                gasStationName = this.gasStationName,
                fuelType = this.fuelType.toFirestore().value,
                pushToken = pushToken,
                enabled = this.isEnabled,
            )
        }
        
        fun fromFirestoreToResponse(document: DocumentSnapshot): AlertDomainModel? =
            try {
                AlertDomainModel(
                    priceCents = requireNotNull(document.getLong("priceCents")?.toInt()),
                    gasStationId = requireNotNull(document.getLong("gasStationId")?.toInt()),
                    gasStationName = requireNotNull(document.getString("gasStationName")),
                    fuelType = requireNotNull(
                        AlertFirestoreFuelTypeEnum.toDomain(
                            document.getLong("fuelType")?.toInt()!!
                        )
                    ),
                    isEnabled = requireNotNull(document.getBoolean("enabled")),
                )
            } catch (exception: Exception) {
                null
            }
    }
}