package com.jrl.fuelprice.data.commons.db

import android.content.Context
import androidx.room.Room
import com.jrl.fuelprice.data.alerts.local.dao.AlertDao
import com.jrl.fuelprice.data.discounts.db.dao.DiscountDao
import com.jrl.fuelprice.data.gasstations.db.dao.BrandDao
import com.jrl.fuelprice.data.gasstations.db.dao.GasStationDao
import com.jrl.fuelprice.data.rating.db.dao.RatingDao
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.android.qualifiers.ApplicationContext
import dagger.hilt.components.SingletonComponent

@Module
@InstallIn(SingletonComponent::class)
object DbModule {
    
    private const val DB_NAME = "fuel_price.db"
    
    @Provides
    fun providesAppDatabase(@ApplicationContext context: Context): FuelPriceDb {
        return Room
            .databaseBuilder(context, FuelPriceDb::class.java, DB_NAME)
            .createFromAsset("db/$DB_NAME")
            .build()
    }
    
    @Provides
    fun providesAlertDao(db: FuelPriceDb): AlertDao = db.alertDao()
    
    @Provides
    fun providesBrandDao(db: FuelPriceDb): BrandDao = db.brandDao()
    
    @Provides
    fun providesDiscountDao(db: FuelPriceDb): DiscountDao = db.discountDao()
    
    @Provides
    fun providesGasStationDao(db: FuelPriceDb): GasStationDao = db.gasStationDao()
    
    @Provides
    fun providesRatingDao(db: FuelPriceDb): RatingDao = db.ratingDao()
}