package com.jrl.fuelprice.data.commons.local.lastupdate

import android.util.Log
import com.jrl.fuelprice.data.commons.local.sharedpreferences.PreferencesManager
import java.time.LocalDateTime
import java.time.format.DateTimeFormatter
import java.time.format.DateTimeParseException

abstract class AbsLastUpdateLocalSourceImpl(
    private val preferencesManager: PreferencesManager
) : AbsLastUpdateLocalSource {
    
    companion object {
        const val DATE_TIME_FORMAT = "dd-MM-yyyy HH:mm:ss"
    }
    
    abstract fun getKey(): String
    
    override fun getLastUpdate(): LocalDateTime? {
        val localDateTimeText: String = preferencesManager.getData(getKey(), "")
        if (localDateTimeText.isEmpty()) return null
        return try {
            LocalDateTime.parse(
                localDateTimeText,
                DateTimeFormatter.ofPattern(DATE_TIME_FORMAT)
            )
        } catch (e: DateTimeParseException) {
            Log.e("AbsLocalSourceImpl", "Failed to parse date time: $localDateTimeText", e)
            null
        }
    }
    
    override fun saveLastUpdate(now: LocalDateTime) {
        preferencesManager.saveData(
            getKey(),
            now.format(DateTimeFormatter.ofPattern(DATE_TIME_FORMAT)),
        )
    }
}