package com.jrl.fuelprice.data.commons.local.sharedpreferences

import android.content.Context
import android.content.SharedPreferences
import javax.inject.Inject

class PreferencesManagerImpl @Inject constructor(context: Context) : PreferencesManager {

    private val sharedPreferences: SharedPreferences =
        context.getSharedPreferences("FuelPricePrefs", Context.MODE_PRIVATE)

    override fun <T> saveData(key: String, value: T) {
        val editor = sharedPreferences.edit()
        when (value) {
            is String -> editor.putString(key, value)
            is Boolean -> editor.putBoolean(key, value)
            is Int -> editor.putInt(key, value)
            else -> throw IllegalArgumentException("Unsupported data type")
        }
        editor.apply()
    }

    override fun <T> getData(key: String, defaultValue: T): T {
        return when (defaultValue) {
            is String -> sharedPreferences.getString(key, defaultValue) as T
            is Boolean -> sharedPreferences.getBoolean(key, defaultValue) as T
            is Int -> sharedPreferences.getInt(key, defaultValue) as T
            else -> throw IllegalArgumentException("Unsupported data type")
        }
    }
}