package com.jrl.fuelprice.data.commons.remotes

import com.google.gson.Gson
import com.google.gson.GsonBuilder
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import javax.inject.Singleton

@Module
@InstallIn(SingletonComponent::class)
object NetworkModule {
    
    @Provides
    @Singleton
    fun providesOkHttpClient(): OkHttpClient = OkHttpClient.Builder()
        .retryOnConnectionFailure(true)
        .build()
    
    @Provides
    @Singleton
    fun providesGson(): Gson = GsonBuilder().create()
    
    @Provides
    @Singleton
    fun providesRetrofit(
        okHttpClient: OkHttpClient,
        gson: Gson,
    ): Retrofit {
        val baseUrl = "https://sedeaplicaciones.minetur.gob.es/"
        return Retrofit.Builder()
            .baseUrl(baseUrl)
            .addConverterFactory((GsonConverterFactory.create(gson)))
            .client(okHttpClient)
            .build()
    }
}