package com.jrl.fuelprice.data.gasstations.db

import com.jrl.fuelprice.data.gasstations.db.entities.BrandDbModel
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationDbModel
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationWithBrandDbModel
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import com.jrl.fuelprice.domain.gasstations.models.RadioDomainEnum
import kotlinx.coroutines.flow.Flow

interface GasStationDbSource {
    
    fun getBrands(): List<BrandDbModel>
    
    fun getPagingGasStations(
        fuelType: FuelTypeDomainEnum,
        radio: RadioDomainEnum,
        location: LocationDomainModel?,
        fromIndex: Int,
    ): Flow<List<GasStationWithBrandDbModel>>
    
    fun getGasStationById(
        id: Int,
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): GasStationWithBrandDbModel
    
    suspend fun getFavorites(
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): Flow<List<GasStationWithBrandDbModel>>
    
    suspend fun saveAll(items: List<GasStationDbModel>)
    
    suspend fun updateFavoriteGasStation(gasStationId: Int, isFavorite: Boolean)
}