package com.jrl.fuelprice.data.gasstations.db

import com.jrl.fuelprice.data.gasstations.db.dao.BrandDao
import com.jrl.fuelprice.data.gasstations.db.dao.GasStationDao
import com.jrl.fuelprice.data.gasstations.db.entities.BrandDbModel
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationDbModel
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationWithBrandDbModel
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum.Companion.toText
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import com.jrl.fuelprice.domain.gasstations.models.RadioDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.RadioDomainEnum.Companion.toNumber
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow

class GasStationDbSourceImpl(
    private val gasStationDao: GasStationDao,
    private val brandDao: BrandDao,
) : GasStationDbSource {
    
    companion object {
        private const val PAGE_SIZE = 100
    }
    
    override fun getBrands(): List<BrandDbModel> = brandDao.getAll()
    
    override fun getPagingGasStations(
        fuelType: FuelTypeDomainEnum,
        radio: RadioDomainEnum,
        location: LocationDomainModel?,
        fromIndex: Int,
    ): Flow<List<GasStationWithBrandDbModel>> = flow {
        emit(
            gasStationDao.getGasStationsPagination(
                fuelType = fuelType.toText(),
                radio = radio.toNumber(),
                latitude = location?.latitude ?: 0.0,
                longitude = location?.longitude ?: 0.0,
                pageSize = PAGE_SIZE,
                offset = fromIndex
            )
        )
    }
    
    override fun getGasStationById(
        id: Int,
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): GasStationWithBrandDbModel =
        gasStationDao.getGasStationById(
            id = id,
            fuelType = fuelType.toText(),
            latitude = location?.latitude ?: 0.0,
            longitude = location?.longitude ?: 0.0,
        )
    
    override suspend fun getFavorites(
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): Flow<List<GasStationWithBrandDbModel>> = flow {
        gasStationDao.getFavorites(
            fuelType = fuelType.toText(),
            latitude = location?.latitude ?: 0.0,
            longitude = location?.longitude ?: 0.0,
        ).collect {
            emit(it)
        }
    }
    
    override suspend fun saveAll(items: List<GasStationDbModel>) {
        gasStationDao.insertAll(items)
    }
    
    override suspend fun updateFavoriteGasStation(gasStationId: Int, isFavorite: Boolean) {
        gasStationDao.updateFavorite(gasStationId, isFavorite)
    }
}