package com.jrl.fuelprice.data.gasstations.db.dao

import androidx.room.Dao
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import androidx.room.Transaction
import androidx.room.Update
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationDbModel
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationWithBrandDbModel
import kotlinx.coroutines.flow.Flow

@Dao
interface GasStationDao {
    
    @Query(
        "SELECT *, (latitude-(:latitude))*(latitude-(:latitude))+(longitude-(:longitude))*(longitude-(:longitude)) AS distance_km FROM gas_stations WHERE latitude != 0.0 AND longitude != 0.0 AND ((latitude-(:latitude))*(latitude-(:latitude))+(longitude-(:longitude))*(longitude-(:longitude))) <= (:radio / 111.111) * (:radio / 111.111) AND CASE WHEN :fuelType = 'diesel_a' THEN diesel_a > 0.0 WHEN :fuelType = 'diesel_b' THEN diesel_b > 0.0 WHEN :fuelType = 'diesel_premium' THEN diesel_premium > 0.0 WHEN :fuelType = 'gasoline_95_e5' THEN gasoline_95_e5 > 0.0 WHEN :fuelType = 'gasoline_95_e5_premium' THEN gasoline_95_e5_premium > 0.0 WHEN :fuelType = 'gasoline_95_e10' THEN gasoline_95_e10 > 0.0 WHEN :fuelType = 'gasoline_98_e5' THEN gasoline_98_e5 > 0.0 WHEN :fuelType = 'gasoline_98_e10' THEN gasoline_98_e10 > 0.0 WHEN :fuelType = 'hydrogen' THEN hydrogen > 0.0 END ORDER BY CASE WHEN :fuelType = 'diesel_a' THEN diesel_a WHEN :fuelType = 'diesel_b' THEN diesel_b WHEN :fuelType = 'diesel_premium' THEN diesel_premium WHEN :fuelType = 'gasoline_95_e5' THEN gasoline_95_e5 WHEN :fuelType = 'gasoline_95_e5_premium' THEN gasoline_95_e5_premium WHEN :fuelType = 'gasoline_95_e10' THEN gasoline_95_e10 WHEN :fuelType = 'gasoline_98_e5' THEN gasoline_98_e5 WHEN :fuelType = 'gasoline_98_e10' THEN gasoline_98_e10 WHEN :fuelType = 'hydrogen' THEN hydrogen END ASC LIMIT :pageSize OFFSET :offset"
    )
    fun getGasStationsPagination(
        fuelType: String,
        radio: Int,
        latitude: Double,
        longitude: Double,
        pageSize: Int,
        offset: Int,
    ): List<GasStationWithBrandDbModel>
    
    @Query(
        "SELECT *, (latitude-(:latitude))*(latitude-(:latitude))+(longitude-(:longitude))*(longitude-(:longitude)) AS distance_km FROM gas_stations WHERE id == :id AND latitude != 0.0 AND longitude != 0.0 AND CASE WHEN :fuelType = 'diesel_a' THEN diesel_a > 0.0 WHEN :fuelType = 'diesel_b' THEN diesel_b > 0.0 WHEN :fuelType = 'diesel_premium' THEN diesel_premium > 0.0 WHEN :fuelType = 'gasoline_95_e5' THEN gasoline_95_e5 > 0.0 WHEN :fuelType = 'gasoline_95_e5_premium' THEN gasoline_95_e5_premium > 0.0 WHEN :fuelType = 'gasoline_95_e10' THEN gasoline_95_e10 > 0.0 WHEN :fuelType = 'gasoline_98_e5' THEN gasoline_98_e5 > 0.0 WHEN :fuelType = 'gasoline_98_e10' THEN gasoline_98_e10 > 0.0 WHEN :fuelType = 'hydrogen' THEN hydrogen > 0.0 END ORDER BY CASE WHEN :fuelType = 'diesel_a' THEN diesel_a WHEN :fuelType = 'diesel_b' THEN diesel_b WHEN :fuelType = 'diesel_premium' THEN diesel_premium WHEN :fuelType = 'gasoline_95_e5' THEN gasoline_95_e5 WHEN :fuelType = 'gasoline_95_e5_premium' THEN gasoline_95_e5_premium WHEN :fuelType = 'gasoline_95_e10' THEN gasoline_95_e10 WHEN :fuelType = 'gasoline_98_e5' THEN gasoline_98_e5 WHEN :fuelType = 'gasoline_98_e10' THEN gasoline_98_e10 WHEN :fuelType = 'hydrogen' THEN hydrogen END ASC LIMIT 1"
    )
    fun getGasStationById(
        id: Int,
        fuelType: String,
        latitude: Double,
        longitude: Double,
    ): GasStationWithBrandDbModel
    
    @Query("SELECT *, ((latitude-(:latitude))*(latitude-(:latitude))+(longitude-(:longitude))*(longitude-(:longitude)))*3.1415926535/180*63710008 AS distance_km FROM gas_stations WHERE is_favorite LIKE 1 AND latitude != 0 AND longitude != 0 AND diesel_a > 0 AND ((latitude-(:latitude))*(latitude-(:latitude))+(longitude-(:longitude))*(longitude-(:longitude))) <= (5 / 111.111) * (5 / 111.111) ORDER BY :fuelType, distance_km ASC")
    fun getFavorites(
        fuelType: String,
        latitude: Double,
        longitude: Double,
    ): Flow<List<GasStationWithBrandDbModel>>
    
    @Query("UPDATE gas_stations SET is_favorite = :isFavorite WHERE id = :gasStationId")
    fun updateFavorite(gasStationId: Int, isFavorite: Boolean): Int
    
    @Transaction
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insertAll(gasStations: List<GasStationDbModel>)
    
    @Transaction
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insert(gasStation: GasStationDbModel)
    
    @Update(onConflict = OnConflictStrategy.REPLACE)
    fun update(gasStation: GasStationDbModel): Int
}