package com.jrl.fuelprice.data.gasstations.db.entities

import androidx.room.ColumnInfo
import androidx.room.Embedded
import androidx.room.Relation
import com.jrl.fuelprice.data.discounts.db.entities.DiscountsWithBrandDbModel
import com.jrl.fuelprice.data.gasstations.db.entities.GasStationDbModel.Companion.toDomain
import com.jrl.fuelprice.data.rating.db.entities.RatingDbModel
import com.jrl.fuelprice.data.rating.db.entities.RatingTypeDbEnum
import com.jrl.fuelprice.domain.gasstations.models.GasStationDomainModel
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel

data class GasStationWithBrandDbModel(
    @Embedded val gasStationDbModel: GasStationDbModel,
    @Relation(parentColumn = "brand_id", entityColumn = "id") val brandDbModel: BrandDbModel,
    @Relation(parentColumn = "id", entityColumn = "item_id") val ratings: List<RatingDbModel>,
    @ColumnInfo(name = "distance_km") val distanceKm: Double,
) {
    fun toDomain(
        currentLocation: LocationDomainModel?,
        activeDiscounts: List<DiscountsWithBrandDbModel>,
    ): GasStationDomainModel? {
        val brand = brandDbModel.toDomain() ?: return null
        return gasStationDbModel.toDomain(
            brand = brand,
            ratings = ratings.filter { it.type == RatingTypeDbEnum.GAS_STATION },
            currentLocation = currentLocation,
            activeDiscounts = activeDiscounts,
        )
    }
}