package com.jrl.fuelprice.data.gasstations.db.entities

import android.location.Location
import androidx.room.ColumnInfo
import androidx.room.Entity
import com.jrl.fuelprice.domain.gasstations.models.GasStationPlaceDomainModel
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import java.lang.Math.toRadians
import kotlin.math.cos
import kotlin.math.sin

@Entity(tableName = "places")
data class PlaceDbModel(
    @ColumnInfo(name = "municipality_id") val municipalityId: Int,
    @ColumnInfo(name = "municipality_name") val municipalityName: String,
    @ColumnInfo(name = "postal_code") val postalCode: String,
    @ColumnInfo(name = "address") val address: String,
    @ColumnInfo(name = "latitude") val latitude: Double,
    @ColumnInfo(name = "latitude_sin_rad") val latitudeSinRad: Double,
    @ColumnInfo(name = "latitude_cos_rad") val latitudeCosRad: Double,
    @ColumnInfo(name = "longitude") val longitude: Double,
    @ColumnInfo(name = "longitude_sin_rad") val longitudeSinRad: Double,
    @ColumnInfo(name = "longitude_cos_rad") val longitudeCosRad: Double,
) {
    
    companion object {
        fun GasStationPlaceDomainModel.toDb(): PlaceDbModel {
            return PlaceDbModel(
                municipalityId = this.municipalityId,
                municipalityName = this.municipalityName,
                postalCode = this.postalCode,
                address = this.address,
                latitude = this.location.latitude,
                latitudeSinRad = sin(toRadians(this.location.latitude)),
                latitudeCosRad = cos(toRadians(this.location.latitude)),
                longitude = this.location.longitude,
                longitudeSinRad = sin(toRadians(this.location.longitude)),
                longitudeCosRad = cos(toRadians(this.location.longitude)),
            )
        }
    }
    
    fun toDomain(currentLocation: LocationDomainModel?): GasStationPlaceDomainModel? =
        try {
            val distanceKm =
                if (currentLocation != null) {
                    val results = FloatArray(1)
                    Location.distanceBetween(
                        /* startLatitude = */ currentLocation.latitude,
                        /* startLongitude = */ currentLocation.longitude,
                        /* endLatitude = */ latitude,
                        /* endLongitude = */ longitude,
                        /* results = */ results,
                    )
                    results[0] / 1000.0
                } else {
                    0.0f
                }
            GasStationPlaceDomainModel(
                municipalityId = municipalityId,
                municipalityName = municipalityName,
                postalCode = postalCode,
                address = address,
                location = LocationDomainModel(
                    latitude = latitude,
                    longitude = longitude,
                ),
                distanceKm = distanceKm.toDouble(),
            )
        } catch (e: Exception) {
            null
        }
}