package com.jrl.fuelprice.data.gasstations.db.entities

import androidx.room.ColumnInfo
import androidx.room.Entity
import com.jrl.fuelprice.data.discounts.db.entities.DiscountDbModel
import com.jrl.fuelprice.data.discounts.db.entities.DiscountTypeDbEnum
import com.jrl.fuelprice.domain.gasstations.models.PriceDomainModel

@Entity(tableName = "prices")
data class PriceDbModel(
    @ColumnInfo(name = "biodiesel") val biodiesel: Double? = null,
    @ColumnInfo(name = "diesel_a") val dieselA: Double? = null,
    @ColumnInfo(name = "diesel_b") val dieselB: Double? = null,
    @ColumnInfo(name = "diesel_premium") val dieselPremium: Double? = null,
    @ColumnInfo(name = "gasoline_95_e5") val gasoline95e5: Double? = null,
    @ColumnInfo(name = "gasoline_95_e5_Premium") val gasoline95e5Premium: Double? = null,
    @ColumnInfo(name = "gasoline_95_e10") val gasoline95e10: Double? = null,
    @ColumnInfo(name = "gasoline_98_e5") val gasoline98e5: Double? = null,
    @ColumnInfo(name = "gasoline_98_e10") val gasoline98e10: Double? = null,
    @ColumnInfo(name = "hydrogen") val hydrogen: Double? = null,
) {
    
    companion object {
        fun PriceDomainModel.toDb(): PriceDbModel {
            return PriceDbModel(
                biodiesel = this.biodiesel,
                dieselA = this.dieselA,
                dieselB = this.dieselB,
                dieselPremium = this.dieselPremium,
                gasoline95e5 = this.gasoline95e5,
                gasoline95e5Premium = this.gasoline95e5Premium,
                gasoline95e10 = this.gasoline95e10,
                gasoline98e5 = this.gasoline98e5,
                gasoline98e10 = this.gasoline98e10,
                hydrogen = this.hydrogen
            )
        }
    }
    
    fun toDomain(activeDiscount: DiscountDbModel? = null): PriceDomainModel? {
        return try {
            PriceDomainModel(
                biodiesel = activeDiscount.applyDiscount(biodiesel),
                dieselA = activeDiscount.applyDiscount(dieselA),
                dieselB = activeDiscount.applyDiscount(dieselB),
                dieselPremium = activeDiscount.applyDiscount(dieselPremium),
                gasoline95e5 = activeDiscount.applyDiscount(gasoline95e5),
                gasoline95e5Premium = activeDiscount.applyDiscount(gasoline95e5Premium),
                gasoline95e10 = activeDiscount.applyDiscount(gasoline95e10),
                gasoline98e5 = activeDiscount.applyDiscount(gasoline98e5),
                gasoline98e10 = activeDiscount.applyDiscount(gasoline98e10),
                hydrogen = activeDiscount.applyDiscount(hydrogen),
            )
        } catch (e: Exception) {
            null
        }
    }
    
    private fun DiscountDbModel?.applyDiscount(price: Double?): Double? {
        return when (this?.type) {
            DiscountTypeDbEnum.CENTS -> if (price != null) price - (this.value / 100.0) else null
            DiscountTypeDbEnum.PERCENTAGE -> if (price != null) price * (1.0 - this.value / 100.0) else null
            else -> price
        }
    }
}