package com.jrl.fuelprice.data.gasstations.di

import com.jrl.fuelprice.data.alerts.local.AlertLocalSource
import com.jrl.fuelprice.data.commons.local.sharedpreferences.PreferencesManager
import com.jrl.fuelprice.data.discounts.db.DiscountsDbSource
import com.jrl.fuelprice.data.gasstations.GasStationRepositoryImpl
import com.jrl.fuelprice.data.gasstations.db.GasStationDbSource
import com.jrl.fuelprice.data.gasstations.db.GasStationDbSourceImpl
import com.jrl.fuelprice.data.gasstations.db.dao.BrandDao
import com.jrl.fuelprice.data.gasstations.db.dao.GasStationDao
import com.jrl.fuelprice.data.gasstations.local.GasStationLocalSource
import com.jrl.fuelprice.data.gasstations.local.GasStationLocalSourceImpl
import com.jrl.fuelprice.data.gasstations.remote.GasStationApi
import com.jrl.fuelprice.data.gasstations.remote.GasStationRemoteSource
import com.jrl.fuelprice.data.gasstations.remote.GasStationRemoteSourceImpl
import com.jrl.fuelprice.data.rating.db.RatingDbSource
import com.jrl.fuelprice.data.rating.firestore.RatingRemoteSource
import com.jrl.fuelprice.data.rating.local.RatingLocalSource
import com.jrl.fuelprice.domain.gasstations.GasStationRepository
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import retrofit2.Retrofit

@Module
@InstallIn(SingletonComponent::class)
object GasStationRemoteProvidesModule {
    
    @Provides
    fun providesGasStationApi(retrofit: Retrofit): GasStationApi = retrofit.create(GasStationApi::class.java)
    
    @Provides
    fun providesGasStationRepository(
        localSource: GasStationLocalSource,
        remoteSource: GasStationRemoteSource,
        gasStationDbSource: GasStationDbSource,
        ratingLocalSource: RatingLocalSource,
        ratingDbSource: RatingDbSource,
        ratingRemoteSource: RatingRemoteSource,
        alertLocalSource: AlertLocalSource,
        discountsDbSource: DiscountsDbSource,
    ): GasStationRepository = GasStationRepositoryImpl(
        gasStationLocalSource = localSource,
        gasStationRemoteSource = remoteSource,
        gasStationDbSource = gasStationDbSource,
        ratingLocalSource = ratingLocalSource,
        ratingDbSource = ratingDbSource,
        ratingRemoteSource = ratingRemoteSource,
        alertLocalSource = alertLocalSource,
        discountsDbSource = discountsDbSource,
    )
    
    @Provides
    fun providesGasStationLocalSource(
        preferencesManager: PreferencesManager
    ): GasStationLocalSource = GasStationLocalSourceImpl(preferencesManager = preferencesManager)
    
    @Provides
    fun providesGasStationRemoteSource(
        api: GasStationApi
    ): GasStationRemoteSource = GasStationRemoteSourceImpl(api = api)
    
    @Provides
    fun providesGasStationDbSource(
        gasStationDao: GasStationDao,
        brandDao: BrandDao,
    ): GasStationDbSource = GasStationDbSourceImpl(
        gasStationDao = gasStationDao,
        brandDao = brandDao,
    )
}