package com.jrl.fuelprice.data.places

import com.jrl.fuelprice.data.places.remote.PlacesRemoteSource
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import com.jrl.fuelprice.domain.places.PlacesRepository
import com.jrl.fuelprice.domain.places.models.PlaceDomainModel
import javax.inject.Inject

class PlacesRepositoryImpl @Inject constructor(
    private val remoteSource: PlacesRemoteSource,
) : PlacesRepository {
    
    override suspend fun searchPlaces(query: String): Result<List<PlaceDomainModel>> =
        remoteSource.searchPlaces(query)
            .fold(
                onSuccess = { predictions ->
                    val places: List<PlaceDomainModel> = predictions.map { prediction ->
                        PlaceDomainModel(
                            id = prediction.placeId,
                            fullName = prediction.getFullText(null).toString(),
                        )
                    }
                    Result.success(places)
                },
                onFailure = {
                    Result.failure(it)
                },
            )
    
    override suspend fun getLocationByPlaceId(placeId: String): Result<LocationDomainModel> =
        remoteSource.getLocationByPlaceId(placeId)
            .fold(
                onSuccess = { place ->
                    val latitude = place.latLng?.latitude ?: return Result.failure(Exception("No latitude"))
                    val longitude = place.latLng?.longitude ?: return Result.failure(Exception("No longitude"))
                    Result.success(
                        LocationDomainModel(
                            latitude = latitude,
                            longitude = longitude,
                        )
                    )
                },
                onFailure = { return Result.failure(it) },
            )
}