package com.jrl.fuelprice.data.places.remote

import com.google.android.libraries.places.api.model.AutocompletePrediction
import com.google.android.libraries.places.api.model.Place
import com.google.android.libraries.places.api.net.FetchPlaceRequest
import com.google.android.libraries.places.api.net.FindAutocompletePredictionsRequest
import com.google.android.libraries.places.api.net.PlacesClient
import kotlinx.coroutines.suspendCancellableCoroutine
import javax.inject.Inject
import kotlin.coroutines.resume
import kotlin.coroutines.resumeWithException

class PlacesRemoteSourceImpl @Inject constructor(
    private val api: PlacesClient,
) : PlacesRemoteSource {
    
    override suspend fun searchPlaces(query: String): Result<List<AutocompletePrediction>> =
        suspendCancellableCoroutine { continuation ->
            api.findAutocompletePredictions(
                FindAutocompletePredictionsRequest.builder()
                    .setCountries(listOf("ES"))
                    .setQuery(query)
                    .build()
            ).addOnSuccessListener { response ->
                continuation.resume(Result.success(response.autocompletePredictions.toList()))
            }.addOnFailureListener { exception ->
                continuation.resumeWithException(exception)
            }
        }
    
    override suspend fun getLocationByPlaceId(placeId: String): Result<Place> =
        suspendCancellableCoroutine { continuation ->
            api.fetchPlace(
                FetchPlaceRequest.newInstance(placeId, listOf(Place.Field.LAT_LNG))
            ).addOnSuccessListener { response ->
                continuation.resume(Result.success(response.place))
            }.addOnFailureListener { exception ->
                continuation.resumeWithException(exception)
            }
        }
}