package com.jrl.fuelprice.data.rating.firestore

import android.util.Log
import com.google.firebase.firestore.FirebaseFirestore
import com.jrl.fuelprice.data.rating.firestore.models.RatingFirestoreModel
import com.jrl.fuelprice.data.rating.firestore.models.RatingFirestoreModel.Companion.toFirestore
import com.jrl.fuelprice.domain.rating.RatingTypeDomainEnum
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.tasks.await
import kotlinx.coroutines.withContext
import javax.inject.Inject

class RatingRemoteSourceImpl @Inject constructor(
    private val firestore: FirebaseFirestore,
) : RatingRemoteSource {
    
    override suspend fun saveRating(itemId: Int, rating: Int, type: RatingTypeDomainEnum, userId: String) {
        val typeMapped = type.toFirestore()
        firestore.collection(RatingFirestoreModel.KEY_RATINGS_DOCUMENT)
            .document(buildKey(itemId, typeMapped, userId))
            .set(
                RatingFirestoreModel(
                    itemId = itemId,
                    score = rating,
                    type = type.toFirestore(),
                    userId = userId
                )
            )
            .addOnSuccessListener {
                Log.d("FIRESTORE", "Save data successfully")
            }
            .addOnFailureListener {
                Log.e("FIRESTORE", it.message ?: it.cause?.message ?: "Error set ratings on Firestore")
            }
    }
    
    private fun buildKey(itemId: Int, typeMapped: Int, userId: String): String = "${itemId}_${typeMapped}_${userId}"
    
    override suspend fun getRatings(): Result<List<RatingFirestoreModel>> {
        return withContext(Dispatchers.IO) {
            try {
                val snapshot = firestore
                    .collection(RatingFirestoreModel.KEY_RATINGS_DOCUMENT)
                    .get()
                    .await()
                val ratings = snapshot.documents.mapNotNull {
                    it?.let { RatingFirestoreModel.fromFirestoreToResponse(it) }
                }
                Result.success(ratings)
            } catch (exception: Exception) {
                Result.failure(exception)
            }
        }
    }
}