package com.jrl.fuelprice.data.rating.firestore.models

import com.google.firebase.firestore.DocumentSnapshot
import com.jrl.fuelprice.data.rating.db.entities.RatingDbModel
import com.jrl.fuelprice.data.rating.db.entities.RatingTypeDbEnum.Companion.fromNumberToDb
import com.jrl.fuelprice.domain.rating.RatingTypeDomainEnum

data class RatingFirestoreModel(
    val itemId: Int? = null,              // Gas station or brand id
    val score: Int? = null,
    val type: Int? = null,
    val userId: String? = null,
) {
    companion object {
        const val KEY_RATINGS_DOCUMENT = "ratings"
        const val RATING_TYPE_GAS_STATION = 0
        const val RATING_TYPE_BRAND = 1
        
        fun fromFirestoreToResponse(document: DocumentSnapshot): RatingFirestoreModel? =
            try {
                RatingFirestoreModel(
                    itemId = document.getLong("itemId")?.toInt(),
                    score = document.getLong("score")?.toInt(),
                    type = document.getLong("type")?.toInt(),
                    userId = document.getString("userId"),
                )
            } catch (exception: Exception) {
                null
            }
        
        fun RatingFirestoreModel.toDb(): RatingDbModel? {
            return if (this.isValid()) {
                return RatingDbModel(
                    itemId = this.itemId!!,
                    score = this.score!!,
                    type = this.type!!.fromNumberToDb(),
                    userId = this.userId!!
                )
            } else {
                null
            }
        }
        
        fun RatingTypeDomainEnum.toFirestore(): Int =
            when (this) {
                RatingTypeDomainEnum.GAS_STATION -> RATING_TYPE_GAS_STATION
                RatingTypeDomainEnum.BRAND -> RATING_TYPE_BRAND
            }
    }
    
    private fun isValid(): Boolean =
        this.itemId != null
                && this.score != null
                && this.type != null
                && this.userId != null
}