package com.jrl.fuelprice.data.vehicledetails.local

import com.jrl.fuelprice.data.commons.local.sharedpreferences.PreferencesManager
import com.jrl.fuelprice.domain.vehicledetails.models.VehicleDetailsDomainModel
import javax.inject.Inject

class VehicleDetailsLocalSourceImpl @Inject constructor(
    private val preferencesManager: PreferencesManager,
) : VehicleDetailsLocalSource {
    
    companion object {
        const val KEY_CONSUMPTION = "consumption"
        const val CONSUMPTION_DEFAULT_VALUE = 56
        const val KEY_TANK = "tank"
        const val TANK_DEFAULT_VALUE = 50
    }
    
    override fun getVehicleDetails(): VehicleDetailsDomainModel {
        return VehicleDetailsDomainModel(
            consumption = getConsumption(),
            tank = getTank(),
        )
    }
    
    private fun getConsumption(): Double = preferencesManager.getData(
        key = KEY_CONSUMPTION, defaultValue = CONSUMPTION_DEFAULT_VALUE
    ) / 10.0
    
    override fun saveConsumption(value: Double) {
        preferencesManager.saveData(
            key = KEY_CONSUMPTION, value = (value * 10).toInt()
        )
    }
    
    private fun getTank(): Int = preferencesManager.getData(KEY_TANK, TANK_DEFAULT_VALUE)
    
    override fun saveTank(value: Int) {
        preferencesManager.saveData(KEY_TANK, value)
    }
}