package com.jrl.fuelprice.domain.alerts.usecases

import com.jrl.fuelprice.domain.alerts.AlertRepository
import com.jrl.fuelprice.domain.alerts.models.AlertGasStationDomainModel
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.LocationDomainModel
import com.jrl.fuelprice.domain.messaging.MessagingRepository
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow
import javax.inject.Inject

class GetAlertsUseCase @Inject constructor(
    private val alertRepository: AlertRepository,
    private val messagingRepository: MessagingRepository,
) {
    
    suspend operator fun invoke(
        fuelType: FuelTypeDomainEnum,
        location: LocationDomainModel?,
    ): Flow<List<AlertGasStationDomainModel>> = flow {
        val userId = messagingRepository.getToken()
        if (userId.isNullOrEmpty()) {
            emit(emptyList())
        } else {
            alertRepository.getAlerts(
                userId = userId,
                fuelType = fuelType,
                location = location,
            ).collect {
                emit(it)
            }
        }
    }
}