package com.jrl.fuelprice.presentation.alerts

import com.google.common.collect.ImmutableList
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.presentation.alerts.models.AlertGasStationUiModel
import com.jrl.fuelprice.presentation.commons.permissions.location.LocationState
import com.jrl.fuelprice.presentation.commons.viewmodel.UiAction
import com.jrl.fuelprice.presentation.commons.viewmodel.UiModel
import com.jrl.fuelprice.presentation.commons.viewmodel.UiSingleEvent
import com.jrl.fuelprice.presentation.gasstationdetails.models.GasStationUiModel

data class AlertUiModel(
    val priceToAlert: Double,
    val favorites: ImmutableList<AlertGasStationUiModel>,
    val fuelTypeSelected: FuelTypeDomainEnum,
    val fuelTypesToShow: ImmutableList<FuelTypeDomainEnum>,
) : UiModel

sealed class AlertUiAction : UiAction {
    data object Load : AlertUiAction()
    data class OnChangePriceToAlert(val priceToAlert: Double) : AlertUiAction()
    data class OnLoadMore(val currentIndex: Int) : AlertUiAction()
    data class OnClickFavorite(val item: GasStationUiModel) : AlertUiAction()
    data class OnClickAlert(val item: AlertGasStationUiModel) : AlertUiAction()
    data class OnClickFuelType(val fuelType: FuelTypeDomainEnum) : AlertUiAction()
    data class OnLocation(val locationState: LocationState) : AlertUiAction()
}

sealed class AlertUiSingleEvent : UiSingleEvent