package com.jrl.fuelprice.presentation.alerts.models

import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.GasStationDomainModel
import com.jrl.fuelprice.domain.vehicledetails.models.VehicleDetailsDomainModel
import com.jrl.fuelprice.presentation.gasstationdetails.models.GasStationUiModel

data class AlertGasStationUiModel(
    val gasStation: GasStationUiModel,
    val isEnabled: Boolean,
) {
    companion object {
        fun toUi(
            gasStation: GasStationDomainModel,
            fuelTypeSelected: FuelTypeDomainEnum,
            vehicleDetails: VehicleDetailsDomainModel,
            isEnabled: Boolean,
        ): AlertGasStationUiModel {
            gasStation.run {
                val priceSelected = when (fuelTypeSelected) {
                    FuelTypeDomainEnum.BIODIESEL -> prices.biodiesel
                    FuelTypeDomainEnum.DIESEL_A -> prices.dieselA
                    FuelTypeDomainEnum.DIESEL_B -> prices.dieselB
                    FuelTypeDomainEnum.DIESEL_PREMIUM -> prices.dieselPremium
                    FuelTypeDomainEnum.GASOLINE_95_E5 -> prices.gasoline95e5
                    FuelTypeDomainEnum.GASOLINE_95_E5_PREMIUM -> prices.gasoline95e5Premium
                    FuelTypeDomainEnum.GASOLINE_95_E10 -> prices.gasoline95e10
                    FuelTypeDomainEnum.GASOLINE_98_E5 -> prices.gasoline98e5
                    FuelTypeDomainEnum.GASOLINE_98_E10 -> prices.gasoline98e10
                    FuelTypeDomainEnum.HYDROGEN -> prices.hydrogen
                }.toString().replace('.', ',')
                return AlertGasStationUiModel(
                    gasStation = GasStationUiModel.toUi(
                        gasStation = this,
                        fuelTypeSelected = fuelTypeSelected,
                        vehicleDetails = vehicleDetails,
                    ),
                    isEnabled = isEnabled
                )
            }
        }
    }
}