package com.jrl.fuelprice.presentation.commons.composables

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.rounded.Close
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import com.jrl.fuelprice.presentation.commons.theme.CustomColor
import com.jrl.fuelprice.presentation.commons.theme.CustomTextStyle
import com.jrl.fuelprice.presentation.commons.theme.Dimension

@Composable
fun CustomTextFieldComposable(
    value: String,
    onValueChange: (value: String) -> Unit,
    modifier: Modifier = Modifier,
    isValid: ((newValue: String) -> Boolean)? = null,
    suffixText: String? = null,
    keyboardOptions: KeyboardOptions = KeyboardOptions.Default,
    height: Dp = 56.dp,
    cornerRadius: Dp = Dimension.Border.Radius,
) {
    var rememberValue by remember { mutableStateOf(value) }
    TextField(
        modifier = modifier
            .height(height)
            .clip(RoundedCornerShape(cornerRadius))
            .fillMaxWidth(),
        value = rememberValue,
        onValueChange = {
            if (isValid == null || isValid(it)) {
                rememberValue = it
                onValueChange(it)
            }
        },
        textStyle = CustomTextStyle.Body,
        singleLine = true,
        colors = TextFieldDefaults.colors()
            .copy(
                unfocusedContainerColor = CustomColor.White,
                focusedContainerColor = CustomColor.White,
                focusedTextColor = CustomColor.Black,
            ),
        suffix = {
            suffixText?.let {
                Text(
                    text = it,
                    style = CustomTextStyle.Hint,
                )
            }
        },
        trailingIcon = {
            IconButton(
                modifier = Modifier.size(24.dp),
                onClick = {
                    rememberValue = ""
                    onValueChange("")
                },
            ) {
                Icon(
                    modifier = Modifier.size(24.dp),
                    imageVector = Icons.Rounded.Close,
                    contentDescription = null,
                )
            }
        },
        keyboardOptions = keyboardOptions,
        shape = RoundedCornerShape(cornerRadius),
    )
}

@Preview
@Composable
fun CustomTextFieldComposablePreview2() {
    Box(
        modifier = Modifier
            .background(CustomColor.Black50)
            .padding(Dimension.Padding.Normal)
    ) {
        CustomTextFieldComposable(
            value = "Text",
            onValueChange = {},
        )
    }
}

@Preview
@Composable
fun CustomTextFieldComposablePreview() {
    Box(
        modifier = Modifier
            .background(CustomColor.Black50)
            .padding(Dimension.Padding.Normal)
    ) {
        CustomTextFieldComposable(
            value = "Text",
            onValueChange = {},
            height = 52.dp,
            cornerRadius = 120.dp,
        )
    }
}
