package com.jrl.fuelprice.presentation.commons.composables

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.rounded.LocalGasStation
import androidx.compose.material.icons.rounded.Star
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.jrl.fuelprice.R
import com.jrl.fuelprice.presentation.commons.theme.CustomColor
import com.jrl.fuelprice.presentation.commons.theme.CustomTextStyle
import com.jrl.fuelprice.presentation.commons.theme.Dimension
import com.jrl.fuelprice.presentation.commons.utils.getBrandImg
import com.jrl.fuelprice.presentation.gasstationdetails.models.GasStationUiModel
import com.jrl.fuelprice.presentation.navigationmaps.models.NavigationMapsUiModel

@Composable
fun ItemGasStationComposable(
    item: GasStationUiModel,
    onClickFavorite: (item: GasStationUiModel) -> Unit,
    onClickNavigateMaps: (NavigationMapsUiModel) -> Unit,
    modifier: Modifier = Modifier,
    onClickDetails: ((gasStationId: Int) -> Unit)? = null,
) {
    Box(
        modifier = modifier
            .fillMaxWidth()
            .background(CustomColor.Transparent)
            .border(
                width = Dimension.Border.Stroke,
                color = CustomColor.Black,
                shape = RoundedCornerShape(Dimension.Border.Radius)
            )
            .padding(Dimension.Padding.Normal)
            .clickable { onClickDetails?.invoke(item.id) },
    ) {
        Row(
            horizontalArrangement = Arrangement.spacedBy(Dimension.Padding.Normal),
        ) {
            getBrandImg(item.brandId)?.let { resImg ->
                Image(
                    modifier = Modifier.size(48.dp),
                    painter = painterResource(resImg),
                    contentDescription = null,
                )
            } ?: run {
                Icon(
                    modifier = Modifier.size(48.dp),
                    imageVector = Icons.Rounded.LocalGasStation,
                    contentDescription = null,
                )
            }
            Column {
                Row {
                    Column(
                        modifier = Modifier
                            .padding(end = Dimension.Padding.VeryLittle)
                            .weight(1f)
                            .fillMaxWidth()
                    ) {
                        Text(
                            text = item.name,
                            style = CustomTextStyle.Body.copy(fontWeight = FontWeight.Bold),
                        )
                        Text(
                            text = "${item.postalCode}, ${item.municipality}",
                            style = CustomTextStyle.Body,
                        )
                    }
                    Column(
                        modifier = Modifier,
                        horizontalAlignment = Alignment.End,
                    ) {
                        Row {
                            var rememberIsFavorite by remember { mutableStateOf(item.isFavorite) }
                            IconButton(
                                modifier = Modifier.size(32.dp),
                                onClick = {
                                    rememberIsFavorite = rememberIsFavorite.not()
                                    onClickFavorite(item.copy(isFavorite = rememberIsFavorite))
                                },
                            ) {
                                Icon(
                                    painter = painterResource(
                                        id = if (rememberIsFavorite) R.drawable.ic_favorite_on else R.drawable.ic_favorite_off
                                    ),
                                    contentDescription = null
                                )
                            }
                            Text(
                                text = item.price,
                                style = CustomTextStyle.TitleLarge.copy(fontSize = 26.sp),
                            )
                        }
                        Text(
                            text = item.updateAtText,
                            style = CustomTextStyle.BodySmall,
                        )
                    }
                }
                Row(
                    modifier = Modifier
                        .padding(top = Dimension.Padding.Little)
                        .fillMaxWidth(),
                    verticalAlignment = Alignment.CenterVertically,
                ) {
                    Row(
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.spacedBy(space = Dimension.Padding.UltraVeryLittle),
                    ) {
                        Text(
                            text = item.scoreText,
                            style = CustomTextStyle.Body,
                        )
                        Icon(
                            modifier = Modifier.size(20.dp),
                            imageVector = Icons.Rounded.Star,
                            contentDescription = null
                        )
                    }
                    Spacer(modifier = Modifier.weight(1f))
                    Row(
                        modifier = Modifier.padding(end = Dimension.Padding.Normal),
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.spacedBy(space = Dimension.Padding.Little),
                    ) {
                        Icon(
                            modifier = Modifier.size(20.dp),
                            painter = painterResource(id = R.drawable.ic_money),
                            contentDescription = null
                        )
                        Text(
                            text = item.costTripTo,
                            style = CustomTextStyle.Body,
                        )
                    }
                    Row(
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.spacedBy(space = Dimension.Padding.VeryLittle),
                    ) {
                        IconButton(
                            modifier = Modifier.size(18.dp),
                            onClick = {
                                onClickNavigateMaps(
                                    NavigationMapsUiModel(
                                        name = item.name,
                                        address = item.address,
                                        postalCode = item.postalCode,
                                        city = item.municipality,
                                        latitude = item.latitude,
                                        longitude = item.longitude,
                                    )
                                )
                            }
                        ) {
                            Icon(
                                modifier = Modifier.size(14.dp),
                                painter = painterResource(id = R.drawable.ic_navigate),
                                contentDescription = null
                            )
                        }
                        Text(
                            text = item.distanceKm,
                            style = CustomTextStyle.Body,
                        )
                    }
                }
            }
        }
    }
}