package com.jrl.fuelprice.presentation.commons.permissions.notifications

import android.Manifest
import android.os.Build
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.rememberCoroutineScope
import com.google.accompanist.permissions.ExperimentalPermissionsApi
import com.google.accompanist.permissions.rememberMultiplePermissionsState
import kotlinx.coroutines.launch

@OptIn(ExperimentalPermissionsApi::class)
@Composable
fun RequestNotificationsPermission(
    onPermissionsGranted: () -> Unit,
    onPermissionsNotGranted: () -> Unit,
) {
    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
        val permissionsState = rememberMultiplePermissionsState(
            permissions = listOf(
                Manifest.permission.POST_NOTIFICATIONS,
            )
        )
        val coroutineScope = rememberCoroutineScope()
        LaunchedEffect(permissionsState.allPermissionsGranted) {
            if (permissionsState.allPermissionsGranted) {
                onPermissionsGranted()
            } else {
                coroutineScope.launch {
                    permissionsState.launchMultiplePermissionRequest()
                    onPermissionsNotGranted()
                }
            }
        }
    } else {
        onPermissionsGranted()
    }
}