package com.jrl.fuelprice.presentation.commons.viewmodel

import android.util.Log
import androidx.lifecycle.ViewModel
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.CoroutineStart
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.Job
import kotlinx.coroutines.SupervisorJob
import kotlinx.coroutines.launch
import kotlin.coroutines.cancellation.CancellationException

abstract class BaseViewModel : ViewModel() {

    private val viewModelJob = SupervisorJob()
    private val viewModelScope = CoroutineScope(Dispatchers.Main + viewModelJob)

    fun launchDefault(block: suspend CoroutineScope.() -> Unit): Job = launch(
        dispatcher = Dispatchers.Default,
        block = block,
        exceptionMessage = "launchDefault"
    )

    fun launchMain(block: suspend CoroutineScope.() -> Unit): Job = launch(
        dispatcher = Dispatchers.Main,
        block = block,
        exceptionMessage = "launchMain"
    )

    fun launchIO(block: suspend CoroutineScope.() -> Unit): Job = launch(
        dispatcher = Dispatchers.IO,
        block = block,
        exceptionMessage = "launchIO"
    )

    private fun launch(
        dispatcher: CoroutineDispatcher,
        start: CoroutineStart = CoroutineStart.DEFAULT,
        block: suspend CoroutineScope.() -> Unit,
        exceptionMessage: String = ""
    ): Job {
        return viewModelScope.launch(
            dispatcher,
            start
        ) {
            try {
                block()
            } catch (cancellationException: CancellationException) {
                // Ignore
            } catch (e: Exception) {
                Log.e(
                    "FUEL_PRICE",
                    "$exceptionMessage---${e.message ?: "Unknown exception"}"
                )
            }
        }
    }

    override fun onCleared() {
        viewModelJob.cancel()
        super.onCleared()
    }
}