package com.jrl.fuelprice.presentation.gasstationdetails

import android.os.Bundle
import androidx.activity.compose.setContent
import androidx.appcompat.app.AppCompatActivity
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import com.jrl.fuelprice.presentation.commons.navigateWithCar
import com.jrl.fuelprice.presentation.commons.theme.FuelPriceTheme
import com.jrl.fuelprice.presentation.navigationmaps.NavigationMapsDialog
import com.jrl.fuelprice.presentation.navigationmaps.models.NavigationMapsUiModel
import dagger.hilt.android.AndroidEntryPoint

@AndroidEntryPoint
class GasStationDetailsActivity : AppCompatActivity() {
    
    companion object {
        const val KEY_GAS_STATION_ID = "gas_station_id"
    }
    
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        intent.getIntExtra(KEY_GAS_STATION_ID, 0).takeIf {
            it > 0
        }?.let {
            setContent {
                val context = LocalContext.current
                var navigationMapsUiModel: NavigationMapsUiModel? = null
                var showDialogNavigationMaps by remember { mutableStateOf(false) }
                
                FuelPriceTheme {
                    GasStationDetailsScreen(
                        gasStationId = it,
                        modifier = Modifier.fillMaxSize(),
                        onClickNavigateMaps = {
                            navigationMapsUiModel = it
                            showDialogNavigationMaps = true
                        },
                    )
                }
                
                if (showDialogNavigationMaps && navigationMapsUiModel != null) {
                    NavigationMapsDialog(
                        navigationMapsUiModel = navigationMapsUiModel!!,
                        onAccept = {
                            navigateWithCar(
                                context = context,
                                latitude = it.latitude,
                                longitude = it.longitude
                            )
                        },
                        onCancel = { showDialogNavigationMaps = false }
                    )
                }
            }
        } ?: this.finish()
    }
}