package com.jrl.fuelprice.presentation.gasstationdetails.models

import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.GasStationDomainModel
import com.jrl.fuelprice.domain.vehicledetails.models.VehicleDetailsDomainModel
import com.jrl.fuelprice.presentation.commons.utils.formatDistance
import com.jrl.fuelprice.presentation.commons.utils.formatPriceWithCurrency
import com.jrl.fuelprice.presentation.commons.utils.getRelativeTimeTextFrom
import java.time.LocalDateTime

data class GasStationUiModel(
    val id: Int,
    val name: String,
    val address: String,
    val brandId: Int,
    val price: String,
    val updateAtText: String,
    val postalCode: String,
    val municipality: String,
    val latitude: Double,
    val longitude: Double,
    val distanceKm: String,
    val scoreText: String,
    val isFavorite: Boolean,
    val costTripTo: String,
) {
    companion object {
        fun toUi(
            gasStation: GasStationDomainModel,
            fuelTypeSelected: FuelTypeDomainEnum,
            vehicleDetails: VehicleDetailsDomainModel,
        ): GasStationUiModel {
            gasStation.run {
                val priceSelected = when (fuelTypeSelected) {
                    FuelTypeDomainEnum.BIODIESEL -> prices.biodiesel
                    FuelTypeDomainEnum.DIESEL_A -> prices.dieselA
                    FuelTypeDomainEnum.DIESEL_B -> prices.dieselB
                    FuelTypeDomainEnum.DIESEL_PREMIUM -> prices.dieselPremium
                    FuelTypeDomainEnum.GASOLINE_95_E5 -> prices.gasoline95e5
                    FuelTypeDomainEnum.GASOLINE_95_E5_PREMIUM -> prices.gasoline95e5Premium
                    FuelTypeDomainEnum.GASOLINE_95_E10 -> prices.gasoline95e10
                    FuelTypeDomainEnum.GASOLINE_98_E5 -> prices.gasoline98e5
                    FuelTypeDomainEnum.GASOLINE_98_E10 -> prices.gasoline98e10
                    FuelTypeDomainEnum.HYDROGEN -> prices.hydrogen
                }
                return GasStationUiModel(
                    id = this.id,
                    name = this.name,
                    address = place.address,
                    brandId = brand.id,
                    price = priceSelected?.formatPriceWithCurrency(decimals = 3) ?: "- €",
                    updateAtText = this.updateAt.getRelativeTimeTextFrom(LocalDateTime.now()),
                    postalCode = place.postalCode,
                    municipality = place.municipalityName,
                    latitude = place.location.latitude,
                    longitude = place.location.longitude,
                    distanceKm = place.distanceKm.formatDistance(),
                    scoreText = this.score.takeIf { it > 0.0 }?.let { "%.1f".format(it) } ?: "-",
                    isFavorite = isFavorite,
                    costTripTo = (vehicleDetails.tank * (priceSelected ?: 0.0)).formatPriceWithCurrency(),
                )
            }
        }
        
        fun buildFuelPricesUi(gasStation: GasStationDomainModel): List<FuelPriceUiModel> =
            listOf(
                FuelPriceUiModel(
                    type = FuelTypeDomainEnum.DIESEL_A,
                    priceText = gasStation.prices.dieselA?.formatPriceWithCurrency(decimals = 3) ?: "- €",
                ),
                FuelPriceUiModel(
                    type = FuelTypeDomainEnum.DIESEL_PREMIUM,
                    priceText = gasStation.prices.dieselPremium?.formatPriceWithCurrency(decimals = 3) ?: "- €",
                ),
                FuelPriceUiModel(
                    type = FuelTypeDomainEnum.GASOLINE_95_E5,
                    priceText = gasStation.prices.gasoline95e5?.formatPriceWithCurrency(decimals = 3) ?: "- €",
                ),
                FuelPriceUiModel(
                    type = FuelTypeDomainEnum.GASOLINE_98_E5,
                    priceText = gasStation.prices.gasoline98e5?.formatPriceWithCurrency(decimals = 3) ?: "- €",
                ),
            )
    }
}