package com.jrl.fuelprice.presentation.home

import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material.BottomNavigation
import androidx.compose.material.BottomNavigationItem
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.navigation.NavDestination.Companion.hierarchy
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.NavHostController
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.jrl.fuelprice.presentation.commons.theme.CustomColor
import com.jrl.fuelprice.presentation.commons.theme.CustomTextStyle
import com.jrl.fuelprice.presentation.commons.theme.Dimension

@Composable
fun HomeBottomBar(
    navController: NavHostController,
    items: List<HomeScreens>,
) {
    BottomNavigation(modifier = Modifier,
        backgroundColor = CustomColor.White,
        contentColor = CustomColor.Primary,
        elevation = 0.dp,
        content = {
            val navBackStackEntry by navController.currentBackStackEntryAsState()
            val currentDestination = navBackStackEntry?.destination
            items.forEach { screen ->
                BottomNavigationItem(modifier = Modifier.padding(vertical = Dimension.Padding.Little),
                    icon = {
                        Icon(
                            modifier = Modifier
                                .padding(bottom = Dimension.Padding.Little)
                                .size(24.dp),
                            painter = painterResource(id = screen.iconId),
                            contentDescription = null,
                            tint = if (currentDestination?.hierarchy?.any { it.route == screen.route } == true) {
                                CustomColor.Primary
                            } else {
                                CustomColor.Black
                            },
                        )
                    },
                    label = {
                        Text(
                            text = stringResource(screen.titleId),
                            style = CustomTextStyle.BodySmall.copy(
                                color = if (currentDestination?.hierarchy?.any { it.route == screen.route } == true) {
                                    CustomColor.Primary
                                } else {
                                    CustomColor.Black
                                },
                                fontWeight = FontWeight.Bold,
                            ),
                        )
                    },
                    selected = currentDestination?.hierarchy?.any { it.route == screen.route } == true,
                    onClick = {
                        navController.navigate(screen.route) {
                            popUpTo(navController.graph.findStartDestination().id) {
                                saveState = true
                            }
                            launchSingleTop = true
                            restoreState = true
                        }
                    }
                )
            }
        }
    )
}

@Preview
@Composable
private fun HomeBottomBarPreview() {
    HomeBottomBar(
        navController = rememberNavController(),
        items = listOf(
            HomeScreens.List,
            HomeScreens.Map,
            HomeScreens.Alerts,
            HomeScreens.VehicleDiscounts,
        ),
    )
}