package com.jrl.fuelprice.presentation.home

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material.AppBarDefaults
import androidx.compose.material.TopAppBar
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.rounded.Search
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import com.jrl.fuelprice.R
import com.jrl.fuelprice.presentation.commons.theme.CustomColor
import com.jrl.fuelprice.presentation.commons.theme.CustomTextStyle

@Composable
fun HomeScreenTopBar(
    onClickSearch: () -> Unit,
) {
    TopAppBar(
        modifier = Modifier,
        backgroundColor = CustomColor.White,
        elevation = AppBarDefaults.TopAppBarElevation,
        contentPadding = AppBarDefaults.ContentPadding,
    ) {
        Box(
            modifier = Modifier.fillMaxSize(), contentAlignment = Alignment.CenterStart
        ) {
            IconButton(
                onClick = onClickSearch,
            ) {
                Icon(
                    imageVector = Icons.Rounded.Search,
                    contentDescription = null,
                    tint = CustomColor.Black,
                )
            }
            Text(
                modifier = Modifier.align(Alignment.Center),
                text = stringResource(R.string.app_name),
                style = CustomTextStyle.TitleMedium,
            )
        }
    }
}

@Preview
@Composable
fun HomeScreenTopBarPreview() {
    HomeScreenTopBar(
        onClickSearch = {},
    )
}