package com.jrl.fuelprice.presentation.listprices

import com.google.common.collect.ImmutableList
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.RadioDomainEnum
import com.jrl.fuelprice.domain.places.models.PlaceDomainModel
import com.jrl.fuelprice.presentation.commons.permissions.location.LocationState
import com.jrl.fuelprice.presentation.commons.viewmodel.UiAction
import com.jrl.fuelprice.presentation.commons.viewmodel.UiModel
import com.jrl.fuelprice.presentation.commons.viewmodel.UiSingleEvent
import com.jrl.fuelprice.presentation.gasstationdetails.models.GasStationUiModel

data class ListPricesUiModel(
    val fuelTypeSelected: FuelTypeDomainEnum,
    val fuelTypesToShow: ImmutableList<FuelTypeDomainEnum>,
    val radioSelected: RadioDomainEnum,
    val radiosToShow: ImmutableList<RadioDomainEnum>,
    val favorites: ImmutableList<GasStationUiModel>,
    val gasStations: ImmutableList<GasStationUiModel>,
) : UiModel

sealed class ListPricesUiAction : UiAction {
    data object Load : ListPricesUiAction()
    data class OnLoadMore(val currentIndex: Int) : ListPricesUiAction()
    data class OnClickFavorite(val item: GasStationUiModel) : ListPricesUiAction()
    data class OnClickFuelType(val fuelType: FuelTypeDomainEnum) : ListPricesUiAction()
    data class OnClickRadio(val radio: RadioDomainEnum) : ListPricesUiAction()
    data class OnLocation(val locationState: LocationState) : ListPricesUiAction()
    data class OnClickPlace(val place: PlaceDomainModel) : ListPricesUiAction()
}

sealed class ListPricesUiSingleEvent : UiSingleEvent