package com.jrl.fuelprice.presentation.listprices.composables

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.AssistChip
import androidx.compose.material3.AssistChipDefaults
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import com.google.common.collect.ImmutableList
import com.jrl.fuelprice.R
import com.jrl.fuelprice.domain.gasstations.models.RadioDomainEnum
import com.jrl.fuelprice.presentation.commons.theme.CustomColor
import com.jrl.fuelprice.presentation.commons.theme.CustomTextStyle
import com.jrl.fuelprice.presentation.commons.theme.Dimension
import com.jrl.fuelprice.presentation.commons.utils.getStringRes

@Composable
fun RadioDropdownMenu(
    itemSelected: RadioDomainEnum,
    items: ImmutableList<RadioDomainEnum>,
    onClick: (fuelType: RadioDomainEnum) -> Unit,
) {
    var expanded by remember { mutableStateOf(false) }
    Box(
        modifier = Modifier
    ) {
        AssistChip(modifier = Modifier,
            onClick = { expanded = true },
            border = BorderStroke(
                width = Dimension.Border.Stroke,
                color = CustomColor.Black
            ),
            colors = AssistChipDefaults.assistChipColors(containerColor = CustomColor.PrimaryLight),
            shape = RoundedCornerShape(Dimension.Border.ChipRadius),
            elevation = AssistChipDefaults.assistChipElevation(0.dp),
            label = {
                Text(
                    modifier = Modifier,
                    color = CustomColor.Black,
                    text = stringResource(id = itemSelected.getStringRes()),
                    style = CustomTextStyle.Body
                )
            },
            trailingIcon = {
                Icon(
                    modifier = Modifier.size(12.dp),
                    painter = painterResource(id = R.drawable.ic_chevron_arrow_down),
                    contentDescription = null,
                    tint = CustomColor.Black,
                )
            }
        )
        DropdownMenu(
            modifier = Modifier.background(CustomColor.White),
            expanded = expanded,
            onDismissRequest = { expanded = false }) {
            items.forEach {
                DropdownMenuItem(
                    modifier = Modifier.background(if (itemSelected == it) CustomColor.PrimaryLight else CustomColor.White),
                    text = {
                        Text(
                            text = stringResource(id = it.getStringRes()),
                            style = if (itemSelected == it) CustomTextStyle.BodyBold else CustomTextStyle.Body
                        )
                    },
                    onClick = {
                        onClick(it)
                        expanded = false
                    }
                )
            }
        }
    }
}