package com.jrl.fuelprice.presentation.map.models

import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.GasStationDomainModel

data class MapGasStationUiModel(
    val id: Int,
    val name: String,
    val brandId: Int,
    val price: String,
    val latitude: Double,
    val longitude: Double,
    val priceLevel: PriceLevelUiEnum,
) {
    companion object {
        fun toUi(
            gasStation: GasStationDomainModel,
            fuelTypeSelected: FuelTypeDomainEnum,
            minPrice: Double,
        ): MapGasStationUiModel {
            gasStation.run {
                val priceSelected = when (fuelTypeSelected) {
                    FuelTypeDomainEnum.BIODIESEL -> prices.biodiesel
                    FuelTypeDomainEnum.DIESEL_A -> prices.dieselA
                    FuelTypeDomainEnum.DIESEL_B -> prices.dieselB
                    FuelTypeDomainEnum.DIESEL_PREMIUM -> prices.dieselPremium
                    FuelTypeDomainEnum.GASOLINE_95_E5 -> prices.gasoline95e5
                    FuelTypeDomainEnum.GASOLINE_95_E5_PREMIUM -> prices.gasoline95e5Premium
                    FuelTypeDomainEnum.GASOLINE_95_E10 -> prices.gasoline95e10
                    FuelTypeDomainEnum.GASOLINE_98_E5 -> prices.gasoline98e5
                    FuelTypeDomainEnum.GASOLINE_98_E10 -> prices.gasoline98e10
                    FuelTypeDomainEnum.HYDROGEN -> prices.hydrogen
                }
                return MapGasStationUiModel(
                    id = this.id,
                    name = this.name,
                    brandId = brand.id,
                    price = priceSelected.toString().replace('.', ','),
                    latitude = place.location.latitude,
                    longitude = place.location.longitude,
                    priceLevel = PriceLevelUiEnum.toUi((priceSelected ?: 0.0) * 100.0 / minPrice),
                )
            }
        }
    }
}