package com.jrl.fuelprice.presentation.messaging

import com.google.firebase.messaging.FirebaseMessagingService
import com.google.firebase.messaging.RemoteMessage
import com.jrl.fuelprice.domain.messaging.SaveTokenUseCase
import com.jrl.fuelprice.presentation.notifications.NotificationService
import dagger.hilt.android.AndroidEntryPoint
import javax.inject.Inject

@AndroidEntryPoint
class CustomFirebaseMessagingService : FirebaseMessagingService() {
    
    @Inject
    lateinit var saveTokenUseCase: SaveTokenUseCase
    
    @Inject
    lateinit var notificationService: NotificationService
    
    override fun onMessageReceived(remoteMessage: RemoteMessage) {
        println("From: ${remoteMessage.from}")
        remoteMessage.data.isNotEmpty().let {
            println("Message data payload: " + remoteMessage.data)
        }
        remoteMessage.notification?.let {
            println("Message Notification Body: ${it.body}")
        }
        notificationService.showBasicNotification(
            title = remoteMessage.notification?.title ?: "Alert price",
            description = remoteMessage.notification?.body ?: "Alert price",
        )
    }
    
    override fun onNewToken(token: String) {
        println("Refreshed token: $token")
        saveTokenUseCase.invoke(token)
    }
}