package com.jrl.fuelprice.presentation.navigationmaps

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.Dialog
import com.jrl.fuelprice.R
import com.jrl.fuelprice.presentation.commons.theme.CustomColor
import com.jrl.fuelprice.presentation.commons.theme.CustomTextStyle
import com.jrl.fuelprice.presentation.commons.theme.Dimension
import com.jrl.fuelprice.presentation.navigationmaps.models.NavigationMapsUiModel

@Composable
fun NavigationMapsDialog(
    navigationMapsUiModel: NavigationMapsUiModel,
    onAccept: (NavigationMapsUiModel) -> Unit,
    onCancel: () -> Unit,
) {
    Dialog(
        onDismissRequest = onCancel,
//        properties = DialogProperties(
//            usePlatformDefaultWidth = false,
//            decorFitsSystemWindows = true,
//        ),
    ) {
        Column(
            modifier = Modifier
                .background(CustomColor.Background, RoundedCornerShape(24.dp))
                .padding(Dimension.Padding.Big)
                .fillMaxWidth(),
        ) {
            Text(
                modifier = Modifier.padding(bottom = Dimension.Padding.VeryBig),
                text = stringResource(id = R.string.navigation_maps_title),
                style = CustomTextStyle.TitleLarge,
            )
            Text(
                modifier = Modifier.padding(bottom = Dimension.Padding.Little),
                text = navigationMapsUiModel.name,
                style = CustomTextStyle.BodyBold,
            )
            Text(
                modifier = Modifier.padding(bottom = Dimension.Padding.UltraVeryLittle),
                text = navigationMapsUiModel.address,
                style = CustomTextStyle.Body,
            )
            Text(
                text = "${navigationMapsUiModel.postalCode} ${navigationMapsUiModel.city}",
                style = CustomTextStyle.Body,
            )
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(top = Dimension.Padding.VeryBig),
                horizontalArrangement = Arrangement.End,
            ) {
                TextButton(
                    onClick = { onCancel() },
                    colors = ButtonDefaults.textButtonColors(contentColor = CustomColor.Black),
                    contentPadding = PaddingValues(Dimension.Padding.Normal)
                ) {
                    Text(
                        text = stringResource(id = R.string.general_cancel),
                        style = CustomTextStyle.BodyBold,
                    )
                }
                TextButton(
                    onClick = { onAccept(navigationMapsUiModel) },
                    colors = ButtonDefaults.textButtonColors(contentColor = CustomColor.Black),
                    contentPadding = PaddingValues(Dimension.Padding.Normal)
                ) {
                    Text(
                        text = stringResource(id = R.string.general_accept),
                        style = CustomTextStyle.BodyBold,
                    )
                }
            }
        }
    }
}

@Preview
@Composable
fun NavigationMapsDialogPreview() {
    NavigationMapsDialog(
        NavigationMapsUiModel(
            name = "Repsol",
            address = "Paseo de la Castellana, 19",
            postalCode = "28051",
            city = "Madrid",
            latitude = 0.0,
            longitude = 0.0,
        ),
        onAccept = {},
        onCancel = {},
    )
}