package com.jrl.fuelprice.presentation.search

import com.jrl.fuelprice.domain.places.models.PlaceDomainModel
import com.jrl.fuelprice.domain.places.usecases.SearchPlacesUseCase
import com.jrl.fuelprice.presentation.commons.extensions.toImmutableList
import com.jrl.fuelprice.presentation.commons.viewmodel.MviViewModel
import com.jrl.fuelprice.presentation.commons.viewmodel.UiState
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class SearchViewModel @Inject constructor(
    private val searchPlacesUseCase: SearchPlacesUseCase,
) : MviViewModel<UiState<SearchUiModel>, SearchUiAction, SearchUiSingleEvent>() {
    
    private var currentQuery: String = ""
    private var currentPlaces: List<PlaceDomainModel> = emptyList()
    
    override fun handleAction(action: SearchUiAction) {
        when (action) {
            SearchUiAction.Load -> submitUiState()
            is SearchUiAction.OnSearch -> onSearchPlaces(action.query)
        }
    }
    
    private fun onSearchPlaces(query: String) {
        currentQuery = query
        launchIO {
            searchPlacesUseCase.invoke(query)
                .onSuccess {
                    currentPlaces = it
                    submitUiState()
                }
                .onFailure { }
        }
    }
    
    private fun submitUiState() {
        submitState(
            UiState.Success(
                SearchUiModel(
                    searchText = currentQuery,
                    places = currentPlaces.toImmutableList(),
                )
            )
        )
    }
}
    
 