package com.jrl.fuelprice.data.gasstations.remote

import com.jrl.fuelprice.data.commons.AbsRemoteTest
import com.jrl.fuelprice.data.commons.buildApiTest
import com.jrl.fuelprice.data.commons.enqueueResponse
import kotlinx.coroutines.test.runTest
import org.junit.jupiter.api.BeforeEach
import org.junit.jupiter.params.ParameterizedTest
import org.junit.jupiter.params.provider.Arguments
import org.junit.jupiter.params.provider.MethodSource
import kotlin.test.assertEquals

class GasStationRemoteSourceImplTest : AbsRemoteTest() {
    
    private lateinit var remote: GasStationRemoteSource
    
    companion object {
        @JvmStatic
        fun getArguments() = listOf<Arguments>(
            Arguments.of(
                200,                                // HTTP status code
                "get_fuel_stations_ok.json",        // response file
                true,                               // API success
                3,                                  // gas stations size
            ),
            Arguments.of(
                400,
                "get_fuel_stations_error.json",
                false,
                0,
            ),
        )
    }
    
    @BeforeEach
    override fun setUp() {
        super.setUp()
        remote = GasStationRemoteSourceImpl(
            api = buildApiTest<GasStationApi>(mockWebServer, gson, okHttpClient),
        )
    }
    
    @ParameterizedTest(name = "GIVEN gas stations with status code {0} WHEN call get gas stations api THEN return {3} alerts")
    @MethodSource("getArguments")
    fun `REMOTE get gas stations`(
        httpCode: Int,
        responseFileName: String,
        isSuccess: Boolean,
        alertsSize: Int,
    ) = runTest {
        // 🔵 Given //
        mockWebServer.enqueueResponse(responseFileName, httpCode)
        
        // 🟡 When //
        val result = remote.getStations()
        
        // 🟢 Then //
        assertEquals(expected = isSuccess, actual = result.isSuccess)
        assertEquals(expected = alertsSize, actual = result.getOrElse { emptyList() }.size)
    }
}