package com.jrl.fuelprice.domain.discounts.usecases

import com.jrl.fuelprice.domain.discounts.DiscountsRepository
import com.jrl.fuelprice.domain.discounts.models.DiscountDomainModel
import com.jrl.fuelprice.domain.discounts.models.DiscountDomainModelTest
import com.jrl.fuelprice.shared.AbsBaseTest
import io.kotest.matchers.shouldBe
import io.mockk.coEvery
import io.mockk.mockk
import kotlinx.coroutines.test.runTest
import org.junit.jupiter.api.BeforeEach
import org.junit.jupiter.params.ParameterizedTest
import org.junit.jupiter.params.provider.Arguments
import org.junit.jupiter.params.provider.MethodSource

class GetDiscountsUseCaseTest : AbsBaseTest() {
    
    private lateinit var useCase: GetDiscountsUseCase
    private val mockDiscountRepository: DiscountsRepository = mockk()
    
    companion object {
        @JvmStatic
        fun getArguments() = listOf<Arguments>(
            Arguments.of(
                true,                              // success
                listOf<DiscountDomainModel>(),     // discounts
            ),
            Arguments.of(
                true,
                listOf(
                    DiscountDomainModelTest.fake()
                )
            ),
            Arguments.of(
                false,
                null
            ),
        )
    }
    
    @BeforeEach
    override fun setUp() {
        super.setUp()
        useCase = GetDiscountsUseCase(
            repository = mockDiscountRepository,
        )
    }
    
    @ParameterizedTest(name = "GIVEN discounts with success {0} WHEN call use case THEN return discounts")
    @MethodSource("getArguments")
    fun `USE CASE get discounts`(
        isSuccess: Boolean,
        discounts: List<DiscountDomainModel>? = null,
    ) = runTest {
        // 🔵 Given //
        coEvery {
            mockDiscountRepository.getDiscounts()
        } returns if (isSuccess) Result.success(discounts!!) else Result.failure(Exception(""))
        
        // 🟡 When //
        val actualResult = useCase.invoke()
        
        // 🟢 Then //
        if (isSuccess) {
            assert(actualResult.isSuccess)
            actualResult.getOrThrow().shouldBe(discounts)
        } else {
            assert(actualResult.isSuccess.not())
            actualResult.getOrNull().shouldBe(discounts)
        }
    }
}