package com.jrl.fuelprice.domain.places.usecases

import com.jrl.fuelprice.domain.places.PlacesRepository
import com.jrl.fuelprice.domain.places.models.PlaceDomainModel
import com.jrl.fuelprice.domain.places.models.PlaceDomainModelTest
import com.jrl.fuelprice.shared.AbsBaseTest
import io.kotest.matchers.shouldBe
import io.mockk.coEvery
import io.mockk.mockk
import kotlinx.coroutines.test.runTest
import org.junit.jupiter.api.BeforeEach
import org.junit.jupiter.params.ParameterizedTest
import org.junit.jupiter.params.provider.Arguments
import org.junit.jupiter.params.provider.MethodSource

class SearchPlacesUseCaseTest : AbsBaseTest() {
    
    private lateinit var useCase: SearchPlacesUseCase
    private val mockPlacesRepository: PlacesRepository = mockk()
    
    companion object {
        @JvmStatic
        fun getArguments() = listOf<Arguments>(
            Arguments.of(
                "qwe",                          // query
                true,                           // success
                listOf<PlaceDomainModel>(),     // places
            ),
            Arguments.of(
                "tol",
                true,
                listOf(PlaceDomainModelTest.fakeList())
            ),
            Arguments.of(
                "toled",
                true,
                listOf(PlaceDomainModelTest.fakeList().filter { it.fullName.contains("toled") })
            ),
            Arguments.of(
                "tol123edo",
                false,
                null
            ),
        )
    }
    
    @BeforeEach
    override fun setUp() {
        super.setUp()
        useCase = SearchPlacesUseCase(
            repository = mockPlacesRepository,
        )
    }
    
    @ParameterizedTest(name = "GIVEN query with success {0} WHEN call use case THEN return places")
    @MethodSource("getArguments")
    fun `USE CASE search places`(
        query: String,
        isSuccess: Boolean,
        places: List<PlaceDomainModel>? = null,
    ) = runTest {
        // 🔵 Given //
        coEvery {
            mockPlacesRepository.searchPlaces(query)
        } returns if (isSuccess) Result.success(places!!) else Result.failure(Exception(""))
        
        // 🟡 When //
        val actualResult = useCase.invoke(query)
        
        // 🟢 Then //
        if (isSuccess) {
            assert(actualResult.isSuccess)
            actualResult.getOrThrow().shouldBe(places)
        } else {
            assert(actualResult.isSuccess.not())
            actualResult.getOrNull().shouldBe(places)
        }
    }
}