package com.jrl.fuelprice.presentation.gasstationdetails

import androidx.compose.ui.test.onNodeWithText
import com.google.common.collect.ImmutableList
import com.jrl.fuelprice.domain.gasstations.models.FuelTypeDomainEnum
import com.jrl.fuelprice.domain.gasstations.models.GasStationDomainModelTest
import com.jrl.fuelprice.domain.vehicledetails.models.VehicleDetailsDomainModel
import com.jrl.fuelprice.presentation.gasstationdetails.models.FuelPriceUiModel
import com.jrl.fuelprice.presentation.gasstationdetails.models.GasStationUiModel
import com.jrl.fuelprice.shared.BaseRobolectricTest
import org.junit.Test

class GasStationsDetailsScreenSuccessTest : BaseRobolectricTest() {
    
    @Test
    fun `GIVEN gas station details screen WHEN success THEN show expected layout`() {
        // 🔵 Given //
        val fakeGasStationName = "Fake Gas Station Name"
        val fakePriceDieselA = "1,459 €"
        val fakePriceGasoline95E5 = "1,599 €"
        setContent {
            GasStationDetailsSuccessComposable(
                uiModel = GasStationDetailsUiModel(
                    gasStation = GasStationUiModel.toUi(
                        gasStation = GasStationDomainModelTest.fake().copy(
                            name = fakeGasStationName,
                        ),
                        fuelTypeSelected = FuelTypeDomainEnum.DIESEL_A,
                        vehicleDetails = VehicleDetailsDomainModel(
                            consumption = 0.0,
                            tank = 0
                        )
                    ),
                    fuels = ImmutableList.of(
                        FuelPriceUiModel(FuelTypeDomainEnum.DIESEL_A, fakePriceDieselA),
                        FuelPriceUiModel(FuelTypeDomainEnum.GASOLINE_95_E5, fakePriceGasoline95E5),
                    ),
                    ratingGasStationByUser = 4,
                    ratingBrandByUser = null,
                ),
                onClickFavorite = {},
                onClickNavigateMaps = {},
                onRatingGasStation = {},
                onRatingBrand = {},
            )
        }
        
        // 🟡 When //
        waitForIdle()
        
        // 🟢 Then //
        composeTestRule.onNodeWithText(text = fakeGasStationName, useUnmergedTree = true).assertExists()
        composeTestRule.onNodeWithText(text = fakePriceDieselA, useUnmergedTree = true).assertExists()
        composeTestRule.onNodeWithText(text = fakePriceGasoline95E5, useUnmergedTree = true).assertExists()
    }
}