package com.jrl.fuelprice.presentation.vehiclediscount

import androidx.compose.ui.test.onNodeWithText
import com.google.common.collect.ImmutableList
import com.jrl.fuelprice.R
import com.jrl.fuelprice.domain.discounts.models.DiscountDomainModelTest
import com.jrl.fuelprice.shared.BaseRobolectricTest
import org.junit.Test

class VehicleDiscountSuccessTest : BaseRobolectricTest() {
    
    @Test
    fun `GIVEN success status WHEN open screen THEN show expected layout`() {
        // 🔵 Given //
        val fakeDiscount = DiscountDomainModelTest.fake()
        val fakeConsumption = 5.7
        val fakeTank = 60
        
        setContent {
            VehicleDiscountSuccessComposable(
                uiModel = VehicleDiscountUiModel(
                    consumption = fakeConsumption,
                    tank = fakeTank,
                    discounts = ImmutableList.of(
                        fakeDiscount.copy(id = 1),
                        fakeDiscount.copy(id = 2),
                        fakeDiscount.copy(id = 3),
                    ),
                    discountsEnable = ImmutableList.of(fakeDiscount.copy(id = 3)),
                ),
                onChangeConsumption = {},
                onChangeTank = {},
                onAddDiscount = {},
                onRemoveDiscount = {},
            )
        }
        
        // 🟡 When //
        waitForIdle()
        
        // 🟢 Then //
        composeTestRule.onNodeWithText(text = context.getString(R.string.vehicle_discount_info)).assertExists()
        composeTestRule.onNodeWithText(text = context.getString(R.string.vehicle_discount_consumption_label))
            .assertExists()
        composeTestRule.onNodeWithText(text = context.getString(R.string.vehicle_discount_consumption_hint))
            .assertExists()
        composeTestRule.onNodeWithText(text = context.getString(R.string.vehicle_discount_tank_label)).assertExists()
        composeTestRule.onNodeWithText(text = context.getString(R.string.vehicle_discount_tank_hint)).assertExists()
        composeTestRule.onNodeWithText(text = context.getString(R.string.vehicle_discount_discounts_label))
            .assertExists()
        composeTestRule.onNodeWithText(text = context.getString(R.string.general_add)).assertExists()
        composeTestRule.onNodeWithText(text = fakeConsumption.toString().replace('.', ',')).assertExists()
        composeTestRule.onNodeWithText(text = fakeTank.toString().replace('.', ',')).assertExists()
    }
}