package com.jrl.fuelprice.shared

import android.app.Application
import android.content.Context
import android.content.pm.ActivityInfo
import androidx.activity.ComponentActivity
import androidx.compose.runtime.Composable
import androidx.compose.ui.test.junit4.createAndroidComposeRule
import androidx.compose.ui.test.onRoot
import androidx.compose.ui.test.printToLog
import androidx.test.core.app.ApplicationProvider
import androidx.test.platform.app.InstrumentationRegistry
import io.mockk.MockKAnnotations
import io.mockk.clearAllMocks
import io.mockk.unmockkAll
import org.junit.After
import org.junit.Before
import org.junit.Rule
import org.junit.runner.RunWith
import org.robolectric.RobolectricTestRunner
import org.robolectric.Shadows
import org.robolectric.annotation.Config
import org.robolectric.annotation.GraphicsMode
import org.robolectric.shadows.ShadowCrossProfileApps
import org.robolectric.shadows.ShadowLog

@RunWith(RobolectricTestRunner::class)
@GraphicsMode(GraphicsMode.Mode.NATIVE)
@Config(
    manifest = "AndroidManifest.xml",
    sdk = [
        Config.OLDEST_SDK,
        Config.TARGET_SDK,
        Config.NEWEST_SDK,
    ],
)
open class BaseRobolectricTest {
    
    protected lateinit var context: Context
    
    @get:Rule
    val composeTestRule = createAndroidComposeRule<ComponentActivity>()
    
    @Before
    @Throws(Exception::class)
    open fun setUp() {
        MockKAnnotations.init(this)
        context = InstrumentationRegistry.getInstrumentation().targetContext
        ShadowLog.stream = System.out       // Redirect Logcat to console
        val appContext: Application = ApplicationProvider.getApplicationContext()
        val activityInfo = ActivityInfo().apply {
            name = ShadowCrossProfileApps.StartedMainActivity::class.java.name
            packageName = appContext.packageName
        }
        Shadows.shadowOf(appContext.packageManager).addOrUpdateActivity(activityInfo)
    }
    
    @After
    open fun tearDown() {
        clearAllMocks()
        unmockkAll()
    }
    
    protected fun setContent(composable: @Composable () -> Unit) {
        composeTestRule.setContent(composable)
    }
    
    protected fun waitForIdle() {
        composeTestRule.waitForIdle()
        printLog()
    }
    
    protected fun printLog(tag: String = "COMPOSE") {
        composeTestRule.onRoot().printToLog(tag)
    }
}